from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel.Wallet
import win32more.Windows.Devices.Geolocation
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Storage.Streams
import win32more.Windows.UI
import win32more.Windows.Win32.System.WinRT
class IWalletBarcode(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Wallet.IWalletBarcode'
    _iid_ = Guid('{4f857b29-de80-4ea4-a1cd-81cd084dac27}')
    @winrt_commethod(6)
    def get_Symbology(self) -> win32more.Windows.ApplicationModel.Wallet.WalletBarcodeSymbology: ...
    @winrt_commethod(7)
    def get_Value(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def GetImageAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStreamReference]: ...
    Symbology = property(get_Symbology, None)
    Value = property(get_Value, None)
class IWalletBarcodeFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Wallet.IWalletBarcodeFactory'
    _iid_ = Guid('{30117161-ed9c-469e-bbfd-306c95ea7108}')
    @winrt_commethod(6)
    def CreateWalletBarcode(self, symbology: win32more.Windows.ApplicationModel.Wallet.WalletBarcodeSymbology, value: WinRT_String) -> win32more.Windows.ApplicationModel.Wallet.WalletBarcode: ...
    @winrt_commethod(7)
    def CreateCustomWalletBarcode(self, streamToBarcodeImage: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> win32more.Windows.ApplicationModel.Wallet.WalletBarcode: ...
class IWalletItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Wallet.IWalletItem'
    _iid_ = Guid('{20b54be8-118d-4ec4-996c-b963e7bd3e74}')
    @winrt_commethod(6)
    def get_DisplayName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_DisplayName(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_IsAcknowledged(self) -> Boolean: ...
    @winrt_commethod(10)
    def put_IsAcknowledged(self, value: Boolean) -> Void: ...
    @winrt_commethod(11)
    def get_IssuerDisplayName(self) -> WinRT_String: ...
    @winrt_commethod(12)
    def put_IssuerDisplayName(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(13)
    def get_LastUpdated(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_commethod(14)
    def put_LastUpdated(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]) -> Void: ...
    @winrt_commethod(15)
    def get_Kind(self) -> win32more.Windows.ApplicationModel.Wallet.WalletItemKind: ...
    @winrt_commethod(16)
    def get_Barcode(self) -> win32more.Windows.ApplicationModel.Wallet.WalletBarcode: ...
    @winrt_commethod(17)
    def put_Barcode(self, value: win32more.Windows.ApplicationModel.Wallet.WalletBarcode) -> Void: ...
    @winrt_commethod(18)
    def get_ExpirationDate(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_commethod(19)
    def put_ExpirationDate(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]) -> Void: ...
    @winrt_commethod(20)
    def get_Logo159x159(self) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_commethod(21)
    def put_Logo159x159(self, value: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> Void: ...
    @winrt_commethod(22)
    def get_Logo336x336(self) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_commethod(23)
    def put_Logo336x336(self, value: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> Void: ...
    @winrt_commethod(24)
    def get_Logo99x99(self) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_commethod(25)
    def put_Logo99x99(self, value: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> Void: ...
    @winrt_commethod(26)
    def get_DisplayMessage(self) -> WinRT_String: ...
    @winrt_commethod(27)
    def put_DisplayMessage(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(28)
    def get_IsDisplayMessageLaunchable(self) -> Boolean: ...
    @winrt_commethod(29)
    def put_IsDisplayMessageLaunchable(self, value: Boolean) -> Void: ...
    @winrt_commethod(30)
    def get_LogoText(self) -> WinRT_String: ...
    @winrt_commethod(31)
    def put_LogoText(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(32)
    def get_HeaderColor(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(33)
    def put_HeaderColor(self, value: win32more.Windows.UI.Color) -> Void: ...
    @winrt_commethod(34)
    def get_BodyColor(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(35)
    def put_BodyColor(self, value: win32more.Windows.UI.Color) -> Void: ...
    @winrt_commethod(36)
    def get_HeaderFontColor(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(37)
    def put_HeaderFontColor(self, value: win32more.Windows.UI.Color) -> Void: ...
    @winrt_commethod(38)
    def get_BodyFontColor(self) -> win32more.Windows.UI.Color: ...
    @winrt_commethod(39)
    def put_BodyFontColor(self, value: win32more.Windows.UI.Color) -> Void: ...
    @winrt_commethod(40)
    def get_HeaderBackgroundImage(self) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_commethod(41)
    def put_HeaderBackgroundImage(self, value: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> Void: ...
    @winrt_commethod(42)
    def get_BodyBackgroundImage(self) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_commethod(43)
    def put_BodyBackgroundImage(self, value: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> Void: ...
    @winrt_commethod(44)
    def get_LogoImage(self) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_commethod(45)
    def put_LogoImage(self, value: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> Void: ...
    @winrt_commethod(46)
    def get_PromotionalImage(self) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_commethod(47)
    def put_PromotionalImage(self, value: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> Void: ...
    @winrt_commethod(48)
    def get_RelevantDate(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_commethod(49)
    def put_RelevantDate(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]) -> Void: ...
    @winrt_commethod(50)
    def get_RelevantDateDisplayMessage(self) -> WinRT_String: ...
    @winrt_commethod(51)
    def put_RelevantDateDisplayMessage(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(52)
    def get_TransactionHistory(self) -> win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.ApplicationModel.Wallet.WalletTransaction]: ...
    @winrt_commethod(53)
    def get_RelevantLocations(self) -> win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.ApplicationModel.Wallet.WalletRelevantLocation]: ...
    @winrt_commethod(54)
    def get_IsMoreTransactionHistoryLaunchable(self) -> Boolean: ...
    @winrt_commethod(55)
    def put_IsMoreTransactionHistoryLaunchable(self, value: Boolean) -> Void: ...
    @winrt_commethod(56)
    def get_DisplayProperties(self) -> win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.ApplicationModel.Wallet.WalletItemCustomProperty]: ...
    @winrt_commethod(57)
    def get_Verbs(self) -> win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.ApplicationModel.Wallet.WalletVerb]: ...
    Barcode = property(get_Barcode, put_Barcode)
    BodyBackgroundImage = property(get_BodyBackgroundImage, put_BodyBackgroundImage)
    BodyColor = property(get_BodyColor, put_BodyColor)
    BodyFontColor = property(get_BodyFontColor, put_BodyFontColor)
    DisplayMessage = property(get_DisplayMessage, put_DisplayMessage)
    DisplayName = property(get_DisplayName, put_DisplayName)
    DisplayProperties = property(get_DisplayProperties, None)
    ExpirationDate = property(get_ExpirationDate, put_ExpirationDate)
    HeaderBackgroundImage = property(get_HeaderBackgroundImage, put_HeaderBackgroundImage)
    HeaderColor = property(get_HeaderColor, put_HeaderColor)
    HeaderFontColor = property(get_HeaderFontColor, put_HeaderFontColor)
    Id = property(get_Id, None)
    IsAcknowledged = property(get_IsAcknowledged, put_IsAcknowledged)
    IsDisplayMessageLaunchable = property(get_IsDisplayMessageLaunchable, put_IsDisplayMessageLaunchable)
    IsMoreTransactionHistoryLaunchable = property(get_IsMoreTransactionHistoryLaunchable, put_IsMoreTransactionHistoryLaunchable)
    IssuerDisplayName = property(get_IssuerDisplayName, put_IssuerDisplayName)
    Kind = property(get_Kind, None)
    LastUpdated = property(get_LastUpdated, put_LastUpdated)
    Logo159x159 = property(get_Logo159x159, put_Logo159x159)
    Logo336x336 = property(get_Logo336x336, put_Logo336x336)
    Logo99x99 = property(get_Logo99x99, put_Logo99x99)
    LogoImage = property(get_LogoImage, put_LogoImage)
    LogoText = property(get_LogoText, put_LogoText)
    PromotionalImage = property(get_PromotionalImage, put_PromotionalImage)
    RelevantDate = property(get_RelevantDate, put_RelevantDate)
    RelevantDateDisplayMessage = property(get_RelevantDateDisplayMessage, put_RelevantDateDisplayMessage)
    RelevantLocations = property(get_RelevantLocations, None)
    TransactionHistory = property(get_TransactionHistory, None)
    Verbs = property(get_Verbs, None)
class IWalletItemCustomProperty(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Wallet.IWalletItemCustomProperty'
    _iid_ = Guid('{b94b40f3-fa00-40fd-98dc-9de46697f1e7}')
    @winrt_commethod(6)
    def get_Name(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Name(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_Value(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_Value(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_AutoDetectLinks(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_AutoDetectLinks(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_DetailViewPosition(self) -> win32more.Windows.ApplicationModel.Wallet.WalletDetailViewPosition: ...
    @winrt_commethod(13)
    def put_DetailViewPosition(self, value: win32more.Windows.ApplicationModel.Wallet.WalletDetailViewPosition) -> Void: ...
    @winrt_commethod(14)
    def get_SummaryViewPosition(self) -> win32more.Windows.ApplicationModel.Wallet.WalletSummaryViewPosition: ...
    @winrt_commethod(15)
    def put_SummaryViewPosition(self, value: win32more.Windows.ApplicationModel.Wallet.WalletSummaryViewPosition) -> Void: ...
    AutoDetectLinks = property(get_AutoDetectLinks, put_AutoDetectLinks)
    DetailViewPosition = property(get_DetailViewPosition, put_DetailViewPosition)
    Name = property(get_Name, put_Name)
    SummaryViewPosition = property(get_SummaryViewPosition, put_SummaryViewPosition)
    Value = property(get_Value, put_Value)
class IWalletItemCustomPropertyFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Wallet.IWalletItemCustomPropertyFactory'
    _iid_ = Guid('{d0046a44-61a1-41aa-b259-a5610ab5d575}')
    @winrt_commethod(6)
    def CreateWalletItemCustomProperty(self, name: WinRT_String, value: WinRT_String) -> win32more.Windows.ApplicationModel.Wallet.WalletItemCustomProperty: ...
class IWalletItemFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Wallet.IWalletItemFactory'
    _iid_ = Guid('{53e27470-4f0b-4a3e-99e5-0bbb1eab38d4}')
    @winrt_commethod(6)
    def CreateWalletItem(self, kind: win32more.Windows.ApplicationModel.Wallet.WalletItemKind, displayName: WinRT_String) -> win32more.Windows.ApplicationModel.Wallet.WalletItem: ...
class IWalletItemStore(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Wallet.IWalletItemStore'
    _iid_ = Guid('{7160484b-6d49-48f8-91a9-40a1d0f13ef4}')
    @winrt_commethod(6)
    def AddAsync(self, id: WinRT_String, item: win32more.Windows.ApplicationModel.Wallet.WalletItem) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(7)
    def ClearAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(8)
    def GetWalletItemAsync(self, id: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.Wallet.WalletItem]: ...
    @winrt_commethod(9)
    def GetItemsAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Wallet.WalletItem]]: ...
    @winrt_commethod(10)
    def GetItemsWithKindAsync(self, kind: win32more.Windows.ApplicationModel.Wallet.WalletItemKind) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Wallet.WalletItem]]: ...
    @winrt_commethod(11)
    def ImportItemAsync(self, stream: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.Wallet.WalletItem]: ...
    @winrt_commethod(12)
    def DeleteAsync(self, id: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(13)
    def ShowAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(14)
    def ShowItemAsync(self, id: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(15)
    def UpdateAsync(self, item: win32more.Windows.ApplicationModel.Wallet.WalletItem) -> win32more.Windows.Foundation.IAsyncAction: ...
class IWalletItemStore2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Wallet.IWalletItemStore2'
    _iid_ = Guid('{65e682f0-7009-4a15-bd54-4fff379bffe2}')
    @winrt_commethod(6)
    def add_ItemsChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Wallet.WalletItemStore, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_ItemsChanged(self, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ItemsChanged = event()
class IWalletManagerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Wallet.IWalletManagerStatics'
    _iid_ = Guid('{5111d6b8-c9a4-4c64-b4dd-e1e548001c0d}')
    @winrt_commethod(6)
    def RequestStoreAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.Wallet.WalletItemStore]: ...
class IWalletRelevantLocation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Wallet.IWalletRelevantLocation'
    _iid_ = Guid('{9fd8782a-e3f9-4de1-bab3-bb192e46b3f3}')
    @winrt_commethod(6)
    def get_Position(self) -> win32more.Windows.Devices.Geolocation.BasicGeoposition: ...
    @winrt_commethod(7)
    def put_Position(self, value: win32more.Windows.Devices.Geolocation.BasicGeoposition) -> Void: ...
    @winrt_commethod(8)
    def get_DisplayMessage(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_DisplayMessage(self, value: WinRT_String) -> Void: ...
    DisplayMessage = property(get_DisplayMessage, put_DisplayMessage)
    Position = property(get_Position, put_Position)
class IWalletTransaction(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Wallet.IWalletTransaction'
    _iid_ = Guid('{40e1e940-2606-4519-81cb-bff1c60d1f79}')
    @winrt_commethod(6)
    def get_Description(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Description(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_DisplayAmount(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_DisplayAmount(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def get_IgnoreTimeOfDay(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IgnoreTimeOfDay(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_DisplayLocation(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def put_DisplayLocation(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(14)
    def get_TransactionDate(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_commethod(15)
    def put_TransactionDate(self, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]) -> Void: ...
    @winrt_commethod(16)
    def get_IsLaunchable(self) -> Boolean: ...
    @winrt_commethod(17)
    def put_IsLaunchable(self, value: Boolean) -> Void: ...
    Description = property(get_Description, put_Description)
    DisplayAmount = property(get_DisplayAmount, put_DisplayAmount)
    DisplayLocation = property(get_DisplayLocation, put_DisplayLocation)
    IgnoreTimeOfDay = property(get_IgnoreTimeOfDay, put_IgnoreTimeOfDay)
    IsLaunchable = property(get_IsLaunchable, put_IsLaunchable)
    TransactionDate = property(get_TransactionDate, put_TransactionDate)
class IWalletVerb(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Wallet.IWalletVerb'
    _iid_ = Guid('{17b826d6-e3c1-4c74-8a94-217aadbc4884}')
    @winrt_commethod(6)
    def get_Name(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Name(self, value: WinRT_String) -> Void: ...
    Name = property(get_Name, put_Name)
class IWalletVerbFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Wallet.IWalletVerbFactory'
    _iid_ = Guid('{76012771-be58-4d5e-83ed-58b1669c7ad9}')
    @winrt_commethod(6)
    def CreateWalletVerb(self, name: WinRT_String) -> win32more.Windows.ApplicationModel.Wallet.WalletVerb: ...
class WalletActionKind(Enum, Int32):
    OpenItem = 0
    Transaction = 1
    MoreTransactions = 2
    Message = 3
    Verb = 4
class WalletBarcode(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Wallet.IWalletBarcode
    _classid_ = 'Windows.ApplicationModel.Wallet.WalletBarcode'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.ApplicationModel.Wallet.WalletBarcode.CreateCustomWalletBarcode(*args))
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.ApplicationModel.Wallet.WalletBarcode.CreateWalletBarcode(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateCustomWalletBarcode(cls: win32more.Windows.ApplicationModel.Wallet.IWalletBarcodeFactory, streamToBarcodeImage: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> win32more.Windows.ApplicationModel.Wallet.WalletBarcode: ...
    @winrt_factorymethod
    def CreateWalletBarcode(cls: win32more.Windows.ApplicationModel.Wallet.IWalletBarcodeFactory, symbology: win32more.Windows.ApplicationModel.Wallet.WalletBarcodeSymbology, value: WinRT_String) -> win32more.Windows.ApplicationModel.Wallet.WalletBarcode: ...
    @winrt_mixinmethod
    def get_Symbology(self: win32more.Windows.ApplicationModel.Wallet.IWalletBarcode) -> win32more.Windows.ApplicationModel.Wallet.WalletBarcodeSymbology: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.ApplicationModel.Wallet.IWalletBarcode) -> WinRT_String: ...
    @winrt_mixinmethod
    def GetImageAsync(self: win32more.Windows.ApplicationModel.Wallet.IWalletBarcode) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStreamReference]: ...
    Symbology = property(get_Symbology, None)
    Value = property(get_Value, None)
class WalletBarcodeSymbology(Enum, Int32):
    Invalid = 0
    Upca = 1
    Upce = 2
    Ean13 = 3
    Ean8 = 4
    Itf = 5
    Code39 = 6
    Code128 = 7
    Qr = 8
    Pdf417 = 9
    Aztec = 10
    Custom = 100000
WalletContract: UInt32 = 131072
class WalletDetailViewPosition(Enum, Int32):
    Hidden = 0
    HeaderField1 = 1
    HeaderField2 = 2
    PrimaryField1 = 3
    PrimaryField2 = 4
    SecondaryField1 = 5
    SecondaryField2 = 6
    SecondaryField3 = 7
    SecondaryField4 = 8
    SecondaryField5 = 9
    CenterField1 = 10
    FooterField1 = 11
    FooterField2 = 12
    FooterField3 = 13
    FooterField4 = 14
class WalletItem(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Wallet.IWalletItem
    _classid_ = 'Windows.ApplicationModel.Wallet.WalletItem'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.ApplicationModel.Wallet.WalletItem.CreateWalletItem(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateWalletItem(cls: win32more.Windows.ApplicationModel.Wallet.IWalletItemFactory, kind: win32more.Windows.ApplicationModel.Wallet.WalletItemKind, displayName: WinRT_String) -> win32more.Windows.ApplicationModel.Wallet.WalletItem: ...
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DisplayName(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_IsAcknowledged(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsAcknowledged(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IssuerDisplayName(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_IssuerDisplayName(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_LastUpdated(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_mixinmethod
    def put_LastUpdated(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]) -> Void: ...
    @winrt_mixinmethod
    def get_Kind(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> win32more.Windows.ApplicationModel.Wallet.WalletItemKind: ...
    @winrt_mixinmethod
    def get_Barcode(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> win32more.Windows.ApplicationModel.Wallet.WalletBarcode: ...
    @winrt_mixinmethod
    def put_Barcode(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem, value: win32more.Windows.ApplicationModel.Wallet.WalletBarcode) -> Void: ...
    @winrt_mixinmethod
    def get_ExpirationDate(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_mixinmethod
    def put_ExpirationDate(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]) -> Void: ...
    @winrt_mixinmethod
    def get_Logo159x159(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_mixinmethod
    def put_Logo159x159(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem, value: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> Void: ...
    @winrt_mixinmethod
    def get_Logo336x336(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_mixinmethod
    def put_Logo336x336(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem, value: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> Void: ...
    @winrt_mixinmethod
    def get_Logo99x99(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_mixinmethod
    def put_Logo99x99(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem, value: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayMessage(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DisplayMessage(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_IsDisplayMessageLaunchable(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsDisplayMessageLaunchable(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_LogoText(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_LogoText(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderColor(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> win32more.Windows.UI.Color: ...
    @winrt_mixinmethod
    def put_HeaderColor(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem, value: win32more.Windows.UI.Color) -> Void: ...
    @winrt_mixinmethod
    def get_BodyColor(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> win32more.Windows.UI.Color: ...
    @winrt_mixinmethod
    def put_BodyColor(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem, value: win32more.Windows.UI.Color) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderFontColor(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> win32more.Windows.UI.Color: ...
    @winrt_mixinmethod
    def put_HeaderFontColor(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem, value: win32more.Windows.UI.Color) -> Void: ...
    @winrt_mixinmethod
    def get_BodyFontColor(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> win32more.Windows.UI.Color: ...
    @winrt_mixinmethod
    def put_BodyFontColor(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem, value: win32more.Windows.UI.Color) -> Void: ...
    @winrt_mixinmethod
    def get_HeaderBackgroundImage(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_mixinmethod
    def put_HeaderBackgroundImage(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem, value: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> Void: ...
    @winrt_mixinmethod
    def get_BodyBackgroundImage(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_mixinmethod
    def put_BodyBackgroundImage(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem, value: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> Void: ...
    @winrt_mixinmethod
    def get_LogoImage(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_mixinmethod
    def put_LogoImage(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem, value: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> Void: ...
    @winrt_mixinmethod
    def get_PromotionalImage(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_mixinmethod
    def put_PromotionalImage(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem, value: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> Void: ...
    @winrt_mixinmethod
    def get_RelevantDate(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_mixinmethod
    def put_RelevantDate(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]) -> Void: ...
    @winrt_mixinmethod
    def get_RelevantDateDisplayMessage(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_RelevantDateDisplayMessage(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_TransactionHistory(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.ApplicationModel.Wallet.WalletTransaction]: ...
    @winrt_mixinmethod
    def get_RelevantLocations(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.ApplicationModel.Wallet.WalletRelevantLocation]: ...
    @winrt_mixinmethod
    def get_IsMoreTransactionHistoryLaunchable(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsMoreTransactionHistoryLaunchable(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayProperties(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.ApplicationModel.Wallet.WalletItemCustomProperty]: ...
    @winrt_mixinmethod
    def get_Verbs(self: win32more.Windows.ApplicationModel.Wallet.IWalletItem) -> win32more.Windows.Foundation.Collections.IMap[WinRT_String, win32more.Windows.ApplicationModel.Wallet.WalletVerb]: ...
    Barcode = property(get_Barcode, put_Barcode)
    BodyBackgroundImage = property(get_BodyBackgroundImage, put_BodyBackgroundImage)
    BodyColor = property(get_BodyColor, put_BodyColor)
    BodyFontColor = property(get_BodyFontColor, put_BodyFontColor)
    DisplayMessage = property(get_DisplayMessage, put_DisplayMessage)
    DisplayName = property(get_DisplayName, put_DisplayName)
    DisplayProperties = property(get_DisplayProperties, None)
    ExpirationDate = property(get_ExpirationDate, put_ExpirationDate)
    HeaderBackgroundImage = property(get_HeaderBackgroundImage, put_HeaderBackgroundImage)
    HeaderColor = property(get_HeaderColor, put_HeaderColor)
    HeaderFontColor = property(get_HeaderFontColor, put_HeaderFontColor)
    Id = property(get_Id, None)
    IsAcknowledged = property(get_IsAcknowledged, put_IsAcknowledged)
    IsDisplayMessageLaunchable = property(get_IsDisplayMessageLaunchable, put_IsDisplayMessageLaunchable)
    IsMoreTransactionHistoryLaunchable = property(get_IsMoreTransactionHistoryLaunchable, put_IsMoreTransactionHistoryLaunchable)
    IssuerDisplayName = property(get_IssuerDisplayName, put_IssuerDisplayName)
    Kind = property(get_Kind, None)
    LastUpdated = property(get_LastUpdated, put_LastUpdated)
    Logo159x159 = property(get_Logo159x159, put_Logo159x159)
    Logo336x336 = property(get_Logo336x336, put_Logo336x336)
    Logo99x99 = property(get_Logo99x99, put_Logo99x99)
    LogoImage = property(get_LogoImage, put_LogoImage)
    LogoText = property(get_LogoText, put_LogoText)
    PromotionalImage = property(get_PromotionalImage, put_PromotionalImage)
    RelevantDate = property(get_RelevantDate, put_RelevantDate)
    RelevantDateDisplayMessage = property(get_RelevantDateDisplayMessage, put_RelevantDateDisplayMessage)
    RelevantLocations = property(get_RelevantLocations, None)
    TransactionHistory = property(get_TransactionHistory, None)
    Verbs = property(get_Verbs, None)
class WalletItemCustomProperty(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Wallet.IWalletItemCustomProperty
    _classid_ = 'Windows.ApplicationModel.Wallet.WalletItemCustomProperty'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.ApplicationModel.Wallet.WalletItemCustomProperty.CreateWalletItemCustomProperty(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateWalletItemCustomProperty(cls: win32more.Windows.ApplicationModel.Wallet.IWalletItemCustomPropertyFactory, name: WinRT_String, value: WinRT_String) -> win32more.Windows.ApplicationModel.Wallet.WalletItemCustomProperty: ...
    @winrt_mixinmethod
    def get_Name(self: win32more.Windows.ApplicationModel.Wallet.IWalletItemCustomProperty) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Name(self: win32more.Windows.ApplicationModel.Wallet.IWalletItemCustomProperty, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.ApplicationModel.Wallet.IWalletItemCustomProperty) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Value(self: win32more.Windows.ApplicationModel.Wallet.IWalletItemCustomProperty, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_AutoDetectLinks(self: win32more.Windows.ApplicationModel.Wallet.IWalletItemCustomProperty) -> Boolean: ...
    @winrt_mixinmethod
    def put_AutoDetectLinks(self: win32more.Windows.ApplicationModel.Wallet.IWalletItemCustomProperty, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_DetailViewPosition(self: win32more.Windows.ApplicationModel.Wallet.IWalletItemCustomProperty) -> win32more.Windows.ApplicationModel.Wallet.WalletDetailViewPosition: ...
    @winrt_mixinmethod
    def put_DetailViewPosition(self: win32more.Windows.ApplicationModel.Wallet.IWalletItemCustomProperty, value: win32more.Windows.ApplicationModel.Wallet.WalletDetailViewPosition) -> Void: ...
    @winrt_mixinmethod
    def get_SummaryViewPosition(self: win32more.Windows.ApplicationModel.Wallet.IWalletItemCustomProperty) -> win32more.Windows.ApplicationModel.Wallet.WalletSummaryViewPosition: ...
    @winrt_mixinmethod
    def put_SummaryViewPosition(self: win32more.Windows.ApplicationModel.Wallet.IWalletItemCustomProperty, value: win32more.Windows.ApplicationModel.Wallet.WalletSummaryViewPosition) -> Void: ...
    AutoDetectLinks = property(get_AutoDetectLinks, put_AutoDetectLinks)
    DetailViewPosition = property(get_DetailViewPosition, put_DetailViewPosition)
    Name = property(get_Name, put_Name)
    SummaryViewPosition = property(get_SummaryViewPosition, put_SummaryViewPosition)
    Value = property(get_Value, put_Value)
class WalletItemKind(Enum, Int32):
    Invalid = 0
    Deal = 1
    General = 2
    PaymentInstrument = 3
    Ticket = 4
    BoardingPass = 5
    MembershipCard = 6
class WalletItemStore(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Wallet.IWalletItemStore
    _classid_ = 'Windows.ApplicationModel.Wallet.WalletItemStore'
    @winrt_mixinmethod
    def AddAsync(self: win32more.Windows.ApplicationModel.Wallet.IWalletItemStore, id: WinRT_String, item: win32more.Windows.ApplicationModel.Wallet.WalletItem) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ClearAsync(self: win32more.Windows.ApplicationModel.Wallet.IWalletItemStore) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def GetWalletItemAsync(self: win32more.Windows.ApplicationModel.Wallet.IWalletItemStore, id: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.Wallet.WalletItem]: ...
    @winrt_mixinmethod
    def GetItemsAsync(self: win32more.Windows.ApplicationModel.Wallet.IWalletItemStore) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Wallet.WalletItem]]: ...
    @winrt_mixinmethod
    def GetItemsWithKindAsync(self: win32more.Windows.ApplicationModel.Wallet.IWalletItemStore, kind: win32more.Windows.ApplicationModel.Wallet.WalletItemKind) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Wallet.WalletItem]]: ...
    @winrt_mixinmethod
    def ImportItemAsync(self: win32more.Windows.ApplicationModel.Wallet.IWalletItemStore, stream: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.Wallet.WalletItem]: ...
    @winrt_mixinmethod
    def DeleteAsync(self: win32more.Windows.ApplicationModel.Wallet.IWalletItemStore, id: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ShowAsync(self: win32more.Windows.ApplicationModel.Wallet.IWalletItemStore) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ShowItemAsync(self: win32more.Windows.ApplicationModel.Wallet.IWalletItemStore, id: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def UpdateAsync(self: win32more.Windows.ApplicationModel.Wallet.IWalletItemStore, item: win32more.Windows.ApplicationModel.Wallet.WalletItem) -> win32more.Windows.Foundation.IAsyncAction: ...
class WalletManager(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Wallet.WalletManager'
    @winrt_classmethod
    def RequestStoreAsync(cls: win32more.Windows.ApplicationModel.Wallet.IWalletManagerStatics) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.Wallet.WalletItemStore]: ...
class WalletRelevantLocation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Wallet.IWalletRelevantLocation
    _classid_ = 'Windows.ApplicationModel.Wallet.WalletRelevantLocation'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.ApplicationModel.Wallet.WalletRelevantLocation.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.ApplicationModel.Wallet.WalletRelevantLocation: ...
    @winrt_mixinmethod
    def get_Position(self: win32more.Windows.ApplicationModel.Wallet.IWalletRelevantLocation) -> win32more.Windows.Devices.Geolocation.BasicGeoposition: ...
    @winrt_mixinmethod
    def put_Position(self: win32more.Windows.ApplicationModel.Wallet.IWalletRelevantLocation, value: win32more.Windows.Devices.Geolocation.BasicGeoposition) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayMessage(self: win32more.Windows.ApplicationModel.Wallet.IWalletRelevantLocation) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DisplayMessage(self: win32more.Windows.ApplicationModel.Wallet.IWalletRelevantLocation, value: WinRT_String) -> Void: ...
    DisplayMessage = property(get_DisplayMessage, put_DisplayMessage)
    Position = property(get_Position, put_Position)
class WalletSummaryViewPosition(Enum, Int32):
    Hidden = 0
    Field1 = 1
    Field2 = 2
class WalletTransaction(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Wallet.IWalletTransaction
    _classid_ = 'Windows.ApplicationModel.Wallet.WalletTransaction'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.ApplicationModel.Wallet.WalletTransaction.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.ApplicationModel.Wallet.WalletTransaction: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.ApplicationModel.Wallet.IWalletTransaction) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Description(self: win32more.Windows.ApplicationModel.Wallet.IWalletTransaction, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayAmount(self: win32more.Windows.ApplicationModel.Wallet.IWalletTransaction) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DisplayAmount(self: win32more.Windows.ApplicationModel.Wallet.IWalletTransaction, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_IgnoreTimeOfDay(self: win32more.Windows.ApplicationModel.Wallet.IWalletTransaction) -> Boolean: ...
    @winrt_mixinmethod
    def put_IgnoreTimeOfDay(self: win32more.Windows.ApplicationModel.Wallet.IWalletTransaction, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayLocation(self: win32more.Windows.ApplicationModel.Wallet.IWalletTransaction) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DisplayLocation(self: win32more.Windows.ApplicationModel.Wallet.IWalletTransaction, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_TransactionDate(self: win32more.Windows.ApplicationModel.Wallet.IWalletTransaction) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]: ...
    @winrt_mixinmethod
    def put_TransactionDate(self: win32more.Windows.ApplicationModel.Wallet.IWalletTransaction, value: win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.DateTime]) -> Void: ...
    @winrt_mixinmethod
    def get_IsLaunchable(self: win32more.Windows.ApplicationModel.Wallet.IWalletTransaction) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsLaunchable(self: win32more.Windows.ApplicationModel.Wallet.IWalletTransaction, value: Boolean) -> Void: ...
    Description = property(get_Description, put_Description)
    DisplayAmount = property(get_DisplayAmount, put_DisplayAmount)
    DisplayLocation = property(get_DisplayLocation, put_DisplayLocation)
    IgnoreTimeOfDay = property(get_IgnoreTimeOfDay, put_IgnoreTimeOfDay)
    IsLaunchable = property(get_IsLaunchable, put_IsLaunchable)
    TransactionDate = property(get_TransactionDate, put_TransactionDate)
class WalletVerb(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Wallet.IWalletVerb
    _classid_ = 'Windows.ApplicationModel.Wallet.WalletVerb'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.ApplicationModel.Wallet.WalletVerb.CreateWalletVerb(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateWalletVerb(cls: win32more.Windows.ApplicationModel.Wallet.IWalletVerbFactory, name: WinRT_String) -> win32more.Windows.ApplicationModel.Wallet.WalletVerb: ...
    @winrt_mixinmethod
    def get_Name(self: win32more.Windows.ApplicationModel.Wallet.IWalletVerb) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Name(self: win32more.Windows.ApplicationModel.Wallet.IWalletVerb, value: WinRT_String) -> Void: ...
    Name = property(get_Name, put_Name)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Globalization.NumberFormatting
import win32more.Windows.Win32.System.WinRT
class CurrencyFormatter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Globalization.NumberFormatting.ICurrencyFormatter
    _classid_ = 'Windows.Globalization.NumberFormatting.CurrencyFormatter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.Globalization.NumberFormatting.CurrencyFormatter.CreateCurrencyFormatterCode(*args))
        elif len(args) == 3:
            super().__init__(move=win32more.Windows.Globalization.NumberFormatting.CurrencyFormatter.CreateCurrencyFormatterCodeContext(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateCurrencyFormatterCode(cls: win32more.Windows.Globalization.NumberFormatting.ICurrencyFormatterFactory, currencyCode: WinRT_String) -> win32more.Windows.Globalization.NumberFormatting.CurrencyFormatter: ...
    @winrt_factorymethod
    def CreateCurrencyFormatterCodeContext(cls: win32more.Windows.Globalization.NumberFormatting.ICurrencyFormatterFactory, currencyCode: WinRT_String, languages: win32more.Windows.Foundation.Collections.IIterable[WinRT_String], geographicRegion: WinRT_String) -> win32more.Windows.Globalization.NumberFormatting.CurrencyFormatter: ...
    @winrt_mixinmethod
    def get_Currency(self: win32more.Windows.Globalization.NumberFormatting.ICurrencyFormatter) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Currency(self: win32more.Windows.Globalization.NumberFormatting.ICurrencyFormatter, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Languages(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_mixinmethod
    def get_GeographicRegion(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_IntegerDigits(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> Int32: ...
    @winrt_mixinmethod
    def put_IntegerDigits(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_FractionDigits(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> Int32: ...
    @winrt_mixinmethod
    def put_FractionDigits(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_IsGrouped(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsGrouped(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsDecimalPointAlwaysDisplayed(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsDecimalPointAlwaysDisplayed(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_NumeralSystem(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_NumeralSystem(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ResolvedLanguage(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ResolvedGeographicRegion(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> WinRT_String: ...
    @winrt_mixinmethod
    def FormatInt(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatter2, value: Int64) -> WinRT_String: ...
    @winrt_mixinmethod
    def FormatUInt(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatter2, value: UInt64) -> WinRT_String: ...
    @winrt_mixinmethod
    def FormatDouble(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatter2, value: Double) -> WinRT_String: ...
    @winrt_mixinmethod
    def ParseInt(self: win32more.Windows.Globalization.NumberFormatting.INumberParser, text: WinRT_String) -> win32more.Windows.Foundation.IReference[Int64]: ...
    @winrt_mixinmethod
    def ParseUInt(self: win32more.Windows.Globalization.NumberFormatting.INumberParser, text: WinRT_String) -> win32more.Windows.Foundation.IReference[UInt64]: ...
    @winrt_mixinmethod
    def ParseDouble(self: win32more.Windows.Globalization.NumberFormatting.INumberParser, text: WinRT_String) -> win32more.Windows.Foundation.IReference[Double]: ...
    @winrt_mixinmethod
    def get_Mode(self: win32more.Windows.Globalization.NumberFormatting.ICurrencyFormatter2) -> win32more.Windows.Globalization.NumberFormatting.CurrencyFormatterMode: ...
    @winrt_mixinmethod
    def put_Mode(self: win32more.Windows.Globalization.NumberFormatting.ICurrencyFormatter2, value: win32more.Windows.Globalization.NumberFormatting.CurrencyFormatterMode) -> Void: ...
    @winrt_mixinmethod
    def ApplyRoundingForCurrency(self: win32more.Windows.Globalization.NumberFormatting.ICurrencyFormatter2, roundingAlgorithm: win32more.Windows.Globalization.NumberFormatting.RoundingAlgorithm) -> Void: ...
    @winrt_mixinmethod
    def get_SignificantDigits(self: win32more.Windows.Globalization.NumberFormatting.ISignificantDigitsOption) -> Int32: ...
    @winrt_mixinmethod
    def put_SignificantDigits(self: win32more.Windows.Globalization.NumberFormatting.ISignificantDigitsOption, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_NumberRounder(self: win32more.Windows.Globalization.NumberFormatting.INumberRounderOption) -> win32more.Windows.Globalization.NumberFormatting.INumberRounder: ...
    @winrt_mixinmethod
    def put_NumberRounder(self: win32more.Windows.Globalization.NumberFormatting.INumberRounderOption, value: win32more.Windows.Globalization.NumberFormatting.INumberRounder) -> Void: ...
    @winrt_mixinmethod
    def get_IsZeroSigned(self: win32more.Windows.Globalization.NumberFormatting.ISignedZeroOption) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsZeroSigned(self: win32more.Windows.Globalization.NumberFormatting.ISignedZeroOption, value: Boolean) -> Void: ...
    Currency = property(get_Currency, put_Currency)
    FractionDigits = property(get_FractionDigits, put_FractionDigits)
    GeographicRegion = property(get_GeographicRegion, None)
    IntegerDigits = property(get_IntegerDigits, put_IntegerDigits)
    IsDecimalPointAlwaysDisplayed = property(get_IsDecimalPointAlwaysDisplayed, put_IsDecimalPointAlwaysDisplayed)
    IsGrouped = property(get_IsGrouped, put_IsGrouped)
    IsZeroSigned = property(get_IsZeroSigned, put_IsZeroSigned)
    Languages = property(get_Languages, None)
    Mode = property(get_Mode, put_Mode)
    NumberRounder = property(get_NumberRounder, put_NumberRounder)
    NumeralSystem = property(get_NumeralSystem, put_NumeralSystem)
    ResolvedGeographicRegion = property(get_ResolvedGeographicRegion, None)
    ResolvedLanguage = property(get_ResolvedLanguage, None)
    SignificantDigits = property(get_SignificantDigits, put_SignificantDigits)
class CurrencyFormatterMode(Enum, Int32):
    UseSymbol = 0
    UseCurrencyCode = 1
class DecimalFormatter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Globalization.NumberFormatting.INumberFormatter
    _classid_ = 'Windows.Globalization.NumberFormatting.DecimalFormatter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Globalization.NumberFormatting.DecimalFormatter.CreateInstance(*args))
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.Globalization.NumberFormatting.DecimalFormatter.CreateDecimalFormatter(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Globalization.NumberFormatting.DecimalFormatter: ...
    @winrt_factorymethod
    def CreateDecimalFormatter(cls: win32more.Windows.Globalization.NumberFormatting.IDecimalFormatterFactory, languages: win32more.Windows.Foundation.Collections.IIterable[WinRT_String], geographicRegion: WinRT_String) -> win32more.Windows.Globalization.NumberFormatting.DecimalFormatter: ...
    @winrt_mixinmethod
    def get_Languages(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_mixinmethod
    def get_GeographicRegion(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_IntegerDigits(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> Int32: ...
    @winrt_mixinmethod
    def put_IntegerDigits(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_FractionDigits(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> Int32: ...
    @winrt_mixinmethod
    def put_FractionDigits(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_IsGrouped(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsGrouped(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsDecimalPointAlwaysDisplayed(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsDecimalPointAlwaysDisplayed(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_NumeralSystem(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_NumeralSystem(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ResolvedLanguage(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ResolvedGeographicRegion(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> WinRT_String: ...
    @winrt_mixinmethod
    def FormatInt(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatter, value: Int64) -> WinRT_String: ...
    @winrt_mixinmethod
    def FormatUInt(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatter, value: UInt64) -> WinRT_String: ...
    @winrt_mixinmethod
    def FormatDouble(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatter, value: Double) -> WinRT_String: ...
    @winrt_mixinmethod
    def ParseInt(self: win32more.Windows.Globalization.NumberFormatting.INumberParser, text: WinRT_String) -> win32more.Windows.Foundation.IReference[Int64]: ...
    @winrt_mixinmethod
    def ParseUInt(self: win32more.Windows.Globalization.NumberFormatting.INumberParser, text: WinRT_String) -> win32more.Windows.Foundation.IReference[UInt64]: ...
    @winrt_mixinmethod
    def ParseDouble(self: win32more.Windows.Globalization.NumberFormatting.INumberParser, text: WinRT_String) -> win32more.Windows.Foundation.IReference[Double]: ...
    @winrt_mixinmethod
    def get_SignificantDigits(self: win32more.Windows.Globalization.NumberFormatting.ISignificantDigitsOption) -> Int32: ...
    @winrt_mixinmethod
    def put_SignificantDigits(self: win32more.Windows.Globalization.NumberFormatting.ISignificantDigitsOption, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_NumberRounder(self: win32more.Windows.Globalization.NumberFormatting.INumberRounderOption) -> win32more.Windows.Globalization.NumberFormatting.INumberRounder: ...
    @winrt_mixinmethod
    def put_NumberRounder(self: win32more.Windows.Globalization.NumberFormatting.INumberRounderOption, value: win32more.Windows.Globalization.NumberFormatting.INumberRounder) -> Void: ...
    @winrt_mixinmethod
    def get_IsZeroSigned(self: win32more.Windows.Globalization.NumberFormatting.ISignedZeroOption) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsZeroSigned(self: win32more.Windows.Globalization.NumberFormatting.ISignedZeroOption, value: Boolean) -> Void: ...
    FractionDigits = property(get_FractionDigits, put_FractionDigits)
    GeographicRegion = property(get_GeographicRegion, None)
    IntegerDigits = property(get_IntegerDigits, put_IntegerDigits)
    IsDecimalPointAlwaysDisplayed = property(get_IsDecimalPointAlwaysDisplayed, put_IsDecimalPointAlwaysDisplayed)
    IsGrouped = property(get_IsGrouped, put_IsGrouped)
    IsZeroSigned = property(get_IsZeroSigned, put_IsZeroSigned)
    Languages = property(get_Languages, None)
    NumberRounder = property(get_NumberRounder, put_NumberRounder)
    NumeralSystem = property(get_NumeralSystem, put_NumeralSystem)
    ResolvedGeographicRegion = property(get_ResolvedGeographicRegion, None)
    ResolvedLanguage = property(get_ResolvedLanguage, None)
    SignificantDigits = property(get_SignificantDigits, put_SignificantDigits)
class ICurrencyFormatter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Globalization.NumberFormatting.ICurrencyFormatter'
    _iid_ = Guid('{11730ca5-4b00-41b2-b332-73b12a497d54}')
    @winrt_commethod(6)
    def get_Currency(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Currency(self, value: WinRT_String) -> Void: ...
    Currency = property(get_Currency, put_Currency)
class ICurrencyFormatter2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Globalization.NumberFormatting.ICurrencyFormatter2'
    _iid_ = Guid('{072c2f1d-e7ba-4197-920e-247c92f7dea6}')
    @winrt_commethod(6)
    def get_Mode(self) -> win32more.Windows.Globalization.NumberFormatting.CurrencyFormatterMode: ...
    @winrt_commethod(7)
    def put_Mode(self, value: win32more.Windows.Globalization.NumberFormatting.CurrencyFormatterMode) -> Void: ...
    @winrt_commethod(8)
    def ApplyRoundingForCurrency(self, roundingAlgorithm: win32more.Windows.Globalization.NumberFormatting.RoundingAlgorithm) -> Void: ...
    Mode = property(get_Mode, put_Mode)
class ICurrencyFormatterFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Globalization.NumberFormatting.ICurrencyFormatterFactory'
    _iid_ = Guid('{86c7537e-b938-4aa2-84b0-2c33dc5b1450}')
    @winrt_commethod(6)
    def CreateCurrencyFormatterCode(self, currencyCode: WinRT_String) -> win32more.Windows.Globalization.NumberFormatting.CurrencyFormatter: ...
    @winrt_commethod(7)
    def CreateCurrencyFormatterCodeContext(self, currencyCode: WinRT_String, languages: win32more.Windows.Foundation.Collections.IIterable[WinRT_String], geographicRegion: WinRT_String) -> win32more.Windows.Globalization.NumberFormatting.CurrencyFormatter: ...
class IDecimalFormatterFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Globalization.NumberFormatting.IDecimalFormatterFactory'
    _iid_ = Guid('{0d018c9a-e393-46b8-b830-7a69c8f89fbb}')
    @winrt_commethod(6)
    def CreateDecimalFormatter(self, languages: win32more.Windows.Foundation.Collections.IIterable[WinRT_String], geographicRegion: WinRT_String) -> win32more.Windows.Globalization.NumberFormatting.DecimalFormatter: ...
class IIncrementNumberRounder(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Globalization.NumberFormatting.IIncrementNumberRounder'
    _iid_ = Guid('{70a64ff8-66ab-4155-9da1-739e46764543}')
    @winrt_commethod(6)
    def get_RoundingAlgorithm(self) -> win32more.Windows.Globalization.NumberFormatting.RoundingAlgorithm: ...
    @winrt_commethod(7)
    def put_RoundingAlgorithm(self, value: win32more.Windows.Globalization.NumberFormatting.RoundingAlgorithm) -> Void: ...
    @winrt_commethod(8)
    def get_Increment(self) -> Double: ...
    @winrt_commethod(9)
    def put_Increment(self, value: Double) -> Void: ...
    Increment = property(get_Increment, put_Increment)
    RoundingAlgorithm = property(get_RoundingAlgorithm, put_RoundingAlgorithm)
class INumberFormatter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Globalization.NumberFormatting.INumberFormatter'
    _iid_ = Guid('{a5007c49-7676-4db7-8631-1b6ff265caa9}')
    @winrt_commethod(6)
    def FormatInt(self, value: Int64) -> WinRT_String: ...
    @winrt_commethod(7)
    def FormatUInt(self, value: UInt64) -> WinRT_String: ...
    @winrt_commethod(8)
    def FormatDouble(self, value: Double) -> WinRT_String: ...
class INumberFormatter2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Globalization.NumberFormatting.INumberFormatter2'
    _iid_ = Guid('{d4a8c1f0-80d0-4b0d-a89e-882c1e8f8310}')
    @winrt_commethod(6)
    def FormatInt(self, value: Int64) -> WinRT_String: ...
    @winrt_commethod(7)
    def FormatUInt(self, value: UInt64) -> WinRT_String: ...
    @winrt_commethod(8)
    def FormatDouble(self, value: Double) -> WinRT_String: ...
class INumberFormatterOptions(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Globalization.NumberFormatting.INumberFormatterOptions'
    _iid_ = Guid('{80332d21-aee1-4a39-baa2-07ed8c96daf6}')
    @winrt_commethod(6)
    def get_Languages(self) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_commethod(7)
    def get_GeographicRegion(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_IntegerDigits(self) -> Int32: ...
    @winrt_commethod(9)
    def put_IntegerDigits(self, value: Int32) -> Void: ...
    @winrt_commethod(10)
    def get_FractionDigits(self) -> Int32: ...
    @winrt_commethod(11)
    def put_FractionDigits(self, value: Int32) -> Void: ...
    @winrt_commethod(12)
    def get_IsGrouped(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_IsGrouped(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def get_IsDecimalPointAlwaysDisplayed(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_IsDecimalPointAlwaysDisplayed(self, value: Boolean) -> Void: ...
    @winrt_commethod(16)
    def get_NumeralSystem(self) -> WinRT_String: ...
    @winrt_commethod(17)
    def put_NumeralSystem(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(18)
    def get_ResolvedLanguage(self) -> WinRT_String: ...
    @winrt_commethod(19)
    def get_ResolvedGeographicRegion(self) -> WinRT_String: ...
    FractionDigits = property(get_FractionDigits, put_FractionDigits)
    GeographicRegion = property(get_GeographicRegion, None)
    IntegerDigits = property(get_IntegerDigits, put_IntegerDigits)
    IsDecimalPointAlwaysDisplayed = property(get_IsDecimalPointAlwaysDisplayed, put_IsDecimalPointAlwaysDisplayed)
    IsGrouped = property(get_IsGrouped, put_IsGrouped)
    Languages = property(get_Languages, None)
    NumeralSystem = property(get_NumeralSystem, put_NumeralSystem)
    ResolvedGeographicRegion = property(get_ResolvedGeographicRegion, None)
    ResolvedLanguage = property(get_ResolvedLanguage, None)
class INumberParser(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Globalization.NumberFormatting.INumberParser'
    _iid_ = Guid('{e6659412-4a13-4a53-83a1-392fbe4cff9f}')
    @winrt_commethod(6)
    def ParseInt(self, text: WinRT_String) -> win32more.Windows.Foundation.IReference[Int64]: ...
    @winrt_commethod(7)
    def ParseUInt(self, text: WinRT_String) -> win32more.Windows.Foundation.IReference[UInt64]: ...
    @winrt_commethod(8)
    def ParseDouble(self, text: WinRT_String) -> win32more.Windows.Foundation.IReference[Double]: ...
class INumberRounder(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Globalization.NumberFormatting.INumberRounder'
    _iid_ = Guid('{5473c375-38ed-4631-b80c-ef34fc48b7f5}')
    @winrt_commethod(6)
    def RoundInt32(self, value: Int32) -> Int32: ...
    @winrt_commethod(7)
    def RoundUInt32(self, value: UInt32) -> UInt32: ...
    @winrt_commethod(8)
    def RoundInt64(self, value: Int64) -> Int64: ...
    @winrt_commethod(9)
    def RoundUInt64(self, value: UInt64) -> UInt64: ...
    @winrt_commethod(10)
    def RoundSingle(self, value: Single) -> Single: ...
    @winrt_commethod(11)
    def RoundDouble(self, value: Double) -> Double: ...
class INumberRounderOption(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Globalization.NumberFormatting.INumberRounderOption'
    _iid_ = Guid('{3b088433-646f-4efe-8d48-66eb2e49e736}')
    @winrt_commethod(6)
    def get_NumberRounder(self) -> win32more.Windows.Globalization.NumberFormatting.INumberRounder: ...
    @winrt_commethod(7)
    def put_NumberRounder(self, value: win32more.Windows.Globalization.NumberFormatting.INumberRounder) -> Void: ...
    NumberRounder = property(get_NumberRounder, put_NumberRounder)
class INumeralSystemTranslator(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Globalization.NumberFormatting.INumeralSystemTranslator'
    _iid_ = Guid('{28f5bc2c-8c23-4234-ad2e-fa5a3a426e9b}')
    @winrt_commethod(6)
    def get_Languages(self) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_commethod(7)
    def get_ResolvedLanguage(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_NumeralSystem(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_NumeralSystem(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def TranslateNumerals(self, value: WinRT_String) -> WinRT_String: ...
    Languages = property(get_Languages, None)
    NumeralSystem = property(get_NumeralSystem, put_NumeralSystem)
    ResolvedLanguage = property(get_ResolvedLanguage, None)
class INumeralSystemTranslatorFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Globalization.NumberFormatting.INumeralSystemTranslatorFactory'
    _iid_ = Guid('{9630c8da-36ef-4d88-a85c-6f0d98d620a6}')
    @winrt_commethod(6)
    def Create(self, languages: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Globalization.NumberFormatting.NumeralSystemTranslator: ...
class IPercentFormatterFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Globalization.NumberFormatting.IPercentFormatterFactory'
    _iid_ = Guid('{b7828aef-fed4-4018-a6e2-e09961e03765}')
    @winrt_commethod(6)
    def CreatePercentFormatter(self, languages: win32more.Windows.Foundation.Collections.IIterable[WinRT_String], geographicRegion: WinRT_String) -> win32more.Windows.Globalization.NumberFormatting.PercentFormatter: ...
class IPermilleFormatterFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Globalization.NumberFormatting.IPermilleFormatterFactory'
    _iid_ = Guid('{2b37b4ac-e638-4ed5-a998-62f6b06a49ae}')
    @winrt_commethod(6)
    def CreatePermilleFormatter(self, languages: win32more.Windows.Foundation.Collections.IIterable[WinRT_String], geographicRegion: WinRT_String) -> win32more.Windows.Globalization.NumberFormatting.PermilleFormatter: ...
class ISignedZeroOption(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Globalization.NumberFormatting.ISignedZeroOption'
    _iid_ = Guid('{fd1cdd31-0a3c-49c4-a642-96a1564f4f30}')
    @winrt_commethod(6)
    def get_IsZeroSigned(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsZeroSigned(self, value: Boolean) -> Void: ...
    IsZeroSigned = property(get_IsZeroSigned, put_IsZeroSigned)
class ISignificantDigitsNumberRounder(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Globalization.NumberFormatting.ISignificantDigitsNumberRounder'
    _iid_ = Guid('{f5941bca-6646-4913-8c76-1b191ff94dfd}')
    @winrt_commethod(6)
    def get_RoundingAlgorithm(self) -> win32more.Windows.Globalization.NumberFormatting.RoundingAlgorithm: ...
    @winrt_commethod(7)
    def put_RoundingAlgorithm(self, value: win32more.Windows.Globalization.NumberFormatting.RoundingAlgorithm) -> Void: ...
    @winrt_commethod(8)
    def get_SignificantDigits(self) -> UInt32: ...
    @winrt_commethod(9)
    def put_SignificantDigits(self, value: UInt32) -> Void: ...
    RoundingAlgorithm = property(get_RoundingAlgorithm, put_RoundingAlgorithm)
    SignificantDigits = property(get_SignificantDigits, put_SignificantDigits)
class ISignificantDigitsOption(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Globalization.NumberFormatting.ISignificantDigitsOption'
    _iid_ = Guid('{1d4dfcdd-2d43-4ee8-bbf1-c1b26a711a58}')
    @winrt_commethod(6)
    def get_SignificantDigits(self) -> Int32: ...
    @winrt_commethod(7)
    def put_SignificantDigits(self, value: Int32) -> Void: ...
    SignificantDigits = property(get_SignificantDigits, put_SignificantDigits)
class IncrementNumberRounder(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Globalization.NumberFormatting.INumberRounder
    _classid_ = 'Windows.Globalization.NumberFormatting.IncrementNumberRounder'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Globalization.NumberFormatting.IncrementNumberRounder.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Globalization.NumberFormatting.IncrementNumberRounder: ...
    @winrt_mixinmethod
    def RoundInt32(self: win32more.Windows.Globalization.NumberFormatting.INumberRounder, value: Int32) -> Int32: ...
    @winrt_mixinmethod
    def RoundUInt32(self: win32more.Windows.Globalization.NumberFormatting.INumberRounder, value: UInt32) -> UInt32: ...
    @winrt_mixinmethod
    def RoundInt64(self: win32more.Windows.Globalization.NumberFormatting.INumberRounder, value: Int64) -> Int64: ...
    @winrt_mixinmethod
    def RoundUInt64(self: win32more.Windows.Globalization.NumberFormatting.INumberRounder, value: UInt64) -> UInt64: ...
    @winrt_mixinmethod
    def RoundSingle(self: win32more.Windows.Globalization.NumberFormatting.INumberRounder, value: Single) -> Single: ...
    @winrt_mixinmethod
    def RoundDouble(self: win32more.Windows.Globalization.NumberFormatting.INumberRounder, value: Double) -> Double: ...
    @winrt_mixinmethod
    def get_RoundingAlgorithm(self: win32more.Windows.Globalization.NumberFormatting.IIncrementNumberRounder) -> win32more.Windows.Globalization.NumberFormatting.RoundingAlgorithm: ...
    @winrt_mixinmethod
    def put_RoundingAlgorithm(self: win32more.Windows.Globalization.NumberFormatting.IIncrementNumberRounder, value: win32more.Windows.Globalization.NumberFormatting.RoundingAlgorithm) -> Void: ...
    @winrt_mixinmethod
    def get_Increment(self: win32more.Windows.Globalization.NumberFormatting.IIncrementNumberRounder) -> Double: ...
    @winrt_mixinmethod
    def put_Increment(self: win32more.Windows.Globalization.NumberFormatting.IIncrementNumberRounder, value: Double) -> Void: ...
    Increment = property(get_Increment, put_Increment)
    RoundingAlgorithm = property(get_RoundingAlgorithm, put_RoundingAlgorithm)
class NumeralSystemTranslator(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Globalization.NumberFormatting.INumeralSystemTranslator
    _classid_ = 'Windows.Globalization.NumberFormatting.NumeralSystemTranslator'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Globalization.NumberFormatting.NumeralSystemTranslator.CreateInstance(*args))
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.Globalization.NumberFormatting.NumeralSystemTranslator.Create(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Globalization.NumberFormatting.NumeralSystemTranslator: ...
    @winrt_factorymethod
    def Create(cls: win32more.Windows.Globalization.NumberFormatting.INumeralSystemTranslatorFactory, languages: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Globalization.NumberFormatting.NumeralSystemTranslator: ...
    @winrt_mixinmethod
    def get_Languages(self: win32more.Windows.Globalization.NumberFormatting.INumeralSystemTranslator) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_mixinmethod
    def get_ResolvedLanguage(self: win32more.Windows.Globalization.NumberFormatting.INumeralSystemTranslator) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_NumeralSystem(self: win32more.Windows.Globalization.NumberFormatting.INumeralSystemTranslator) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_NumeralSystem(self: win32more.Windows.Globalization.NumberFormatting.INumeralSystemTranslator, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def TranslateNumerals(self: win32more.Windows.Globalization.NumberFormatting.INumeralSystemTranslator, value: WinRT_String) -> WinRT_String: ...
    Languages = property(get_Languages, None)
    NumeralSystem = property(get_NumeralSystem, put_NumeralSystem)
    ResolvedLanguage = property(get_ResolvedLanguage, None)
class PercentFormatter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Globalization.NumberFormatting.INumberFormatter
    _classid_ = 'Windows.Globalization.NumberFormatting.PercentFormatter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Globalization.NumberFormatting.PercentFormatter.CreateInstance(*args))
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.Globalization.NumberFormatting.PercentFormatter.CreatePercentFormatter(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Globalization.NumberFormatting.PercentFormatter: ...
    @winrt_factorymethod
    def CreatePercentFormatter(cls: win32more.Windows.Globalization.NumberFormatting.IPercentFormatterFactory, languages: win32more.Windows.Foundation.Collections.IIterable[WinRT_String], geographicRegion: WinRT_String) -> win32more.Windows.Globalization.NumberFormatting.PercentFormatter: ...
    @winrt_mixinmethod
    def get_Languages(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_mixinmethod
    def get_GeographicRegion(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_IntegerDigits(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> Int32: ...
    @winrt_mixinmethod
    def put_IntegerDigits(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_FractionDigits(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> Int32: ...
    @winrt_mixinmethod
    def put_FractionDigits(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_IsGrouped(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsGrouped(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsDecimalPointAlwaysDisplayed(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsDecimalPointAlwaysDisplayed(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_NumeralSystem(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_NumeralSystem(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ResolvedLanguage(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ResolvedGeographicRegion(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> WinRT_String: ...
    @winrt_mixinmethod
    def FormatInt(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatter, value: Int64) -> WinRT_String: ...
    @winrt_mixinmethod
    def FormatUInt(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatter, value: UInt64) -> WinRT_String: ...
    @winrt_mixinmethod
    def FormatDouble(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatter, value: Double) -> WinRT_String: ...
    @winrt_mixinmethod
    def ParseInt(self: win32more.Windows.Globalization.NumberFormatting.INumberParser, text: WinRT_String) -> win32more.Windows.Foundation.IReference[Int64]: ...
    @winrt_mixinmethod
    def ParseUInt(self: win32more.Windows.Globalization.NumberFormatting.INumberParser, text: WinRT_String) -> win32more.Windows.Foundation.IReference[UInt64]: ...
    @winrt_mixinmethod
    def ParseDouble(self: win32more.Windows.Globalization.NumberFormatting.INumberParser, text: WinRT_String) -> win32more.Windows.Foundation.IReference[Double]: ...
    @winrt_mixinmethod
    def get_SignificantDigits(self: win32more.Windows.Globalization.NumberFormatting.ISignificantDigitsOption) -> Int32: ...
    @winrt_mixinmethod
    def put_SignificantDigits(self: win32more.Windows.Globalization.NumberFormatting.ISignificantDigitsOption, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_NumberRounder(self: win32more.Windows.Globalization.NumberFormatting.INumberRounderOption) -> win32more.Windows.Globalization.NumberFormatting.INumberRounder: ...
    @winrt_mixinmethod
    def put_NumberRounder(self: win32more.Windows.Globalization.NumberFormatting.INumberRounderOption, value: win32more.Windows.Globalization.NumberFormatting.INumberRounder) -> Void: ...
    @winrt_mixinmethod
    def get_IsZeroSigned(self: win32more.Windows.Globalization.NumberFormatting.ISignedZeroOption) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsZeroSigned(self: win32more.Windows.Globalization.NumberFormatting.ISignedZeroOption, value: Boolean) -> Void: ...
    FractionDigits = property(get_FractionDigits, put_FractionDigits)
    GeographicRegion = property(get_GeographicRegion, None)
    IntegerDigits = property(get_IntegerDigits, put_IntegerDigits)
    IsDecimalPointAlwaysDisplayed = property(get_IsDecimalPointAlwaysDisplayed, put_IsDecimalPointAlwaysDisplayed)
    IsGrouped = property(get_IsGrouped, put_IsGrouped)
    IsZeroSigned = property(get_IsZeroSigned, put_IsZeroSigned)
    Languages = property(get_Languages, None)
    NumberRounder = property(get_NumberRounder, put_NumberRounder)
    NumeralSystem = property(get_NumeralSystem, put_NumeralSystem)
    ResolvedGeographicRegion = property(get_ResolvedGeographicRegion, None)
    ResolvedLanguage = property(get_ResolvedLanguage, None)
    SignificantDigits = property(get_SignificantDigits, put_SignificantDigits)
class PermilleFormatter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Globalization.NumberFormatting.INumberFormatter
    _classid_ = 'Windows.Globalization.NumberFormatting.PermilleFormatter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Globalization.NumberFormatting.PermilleFormatter.CreateInstance(*args))
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.Globalization.NumberFormatting.PermilleFormatter.CreatePermilleFormatter(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Globalization.NumberFormatting.PermilleFormatter: ...
    @winrt_factorymethod
    def CreatePermilleFormatter(cls: win32more.Windows.Globalization.NumberFormatting.IPermilleFormatterFactory, languages: win32more.Windows.Foundation.Collections.IIterable[WinRT_String], geographicRegion: WinRT_String) -> win32more.Windows.Globalization.NumberFormatting.PermilleFormatter: ...
    @winrt_mixinmethod
    def get_Languages(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_mixinmethod
    def get_GeographicRegion(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_IntegerDigits(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> Int32: ...
    @winrt_mixinmethod
    def put_IntegerDigits(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_FractionDigits(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> Int32: ...
    @winrt_mixinmethod
    def put_FractionDigits(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_IsGrouped(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsGrouped(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsDecimalPointAlwaysDisplayed(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsDecimalPointAlwaysDisplayed(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_NumeralSystem(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_NumeralSystem(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_ResolvedLanguage(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ResolvedGeographicRegion(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatterOptions) -> WinRT_String: ...
    @winrt_mixinmethod
    def FormatInt(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatter, value: Int64) -> WinRT_String: ...
    @winrt_mixinmethod
    def FormatUInt(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatter, value: UInt64) -> WinRT_String: ...
    @winrt_mixinmethod
    def FormatDouble(self: win32more.Windows.Globalization.NumberFormatting.INumberFormatter, value: Double) -> WinRT_String: ...
    @winrt_mixinmethod
    def ParseInt(self: win32more.Windows.Globalization.NumberFormatting.INumberParser, text: WinRT_String) -> win32more.Windows.Foundation.IReference[Int64]: ...
    @winrt_mixinmethod
    def ParseUInt(self: win32more.Windows.Globalization.NumberFormatting.INumberParser, text: WinRT_String) -> win32more.Windows.Foundation.IReference[UInt64]: ...
    @winrt_mixinmethod
    def ParseDouble(self: win32more.Windows.Globalization.NumberFormatting.INumberParser, text: WinRT_String) -> win32more.Windows.Foundation.IReference[Double]: ...
    @winrt_mixinmethod
    def get_SignificantDigits(self: win32more.Windows.Globalization.NumberFormatting.ISignificantDigitsOption) -> Int32: ...
    @winrt_mixinmethod
    def put_SignificantDigits(self: win32more.Windows.Globalization.NumberFormatting.ISignificantDigitsOption, value: Int32) -> Void: ...
    @winrt_mixinmethod
    def get_NumberRounder(self: win32more.Windows.Globalization.NumberFormatting.INumberRounderOption) -> win32more.Windows.Globalization.NumberFormatting.INumberRounder: ...
    @winrt_mixinmethod
    def put_NumberRounder(self: win32more.Windows.Globalization.NumberFormatting.INumberRounderOption, value: win32more.Windows.Globalization.NumberFormatting.INumberRounder) -> Void: ...
    @winrt_mixinmethod
    def get_IsZeroSigned(self: win32more.Windows.Globalization.NumberFormatting.ISignedZeroOption) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsZeroSigned(self: win32more.Windows.Globalization.NumberFormatting.ISignedZeroOption, value: Boolean) -> Void: ...
    FractionDigits = property(get_FractionDigits, put_FractionDigits)
    GeographicRegion = property(get_GeographicRegion, None)
    IntegerDigits = property(get_IntegerDigits, put_IntegerDigits)
    IsDecimalPointAlwaysDisplayed = property(get_IsDecimalPointAlwaysDisplayed, put_IsDecimalPointAlwaysDisplayed)
    IsGrouped = property(get_IsGrouped, put_IsGrouped)
    IsZeroSigned = property(get_IsZeroSigned, put_IsZeroSigned)
    Languages = property(get_Languages, None)
    NumberRounder = property(get_NumberRounder, put_NumberRounder)
    NumeralSystem = property(get_NumeralSystem, put_NumeralSystem)
    ResolvedGeographicRegion = property(get_ResolvedGeographicRegion, None)
    ResolvedLanguage = property(get_ResolvedLanguage, None)
    SignificantDigits = property(get_SignificantDigits, put_SignificantDigits)
class RoundingAlgorithm(Enum, Int32):
    None_ = 0
    RoundDown = 1
    RoundUp = 2
    RoundTowardsZero = 3
    RoundAwayFromZero = 4
    RoundHalfDown = 5
    RoundHalfUp = 6
    RoundHalfTowardsZero = 7
    RoundHalfAwayFromZero = 8
    RoundHalfToEven = 9
    RoundHalfToOdd = 10
class SignificantDigitsNumberRounder(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Globalization.NumberFormatting.INumberRounder
    _classid_ = 'Windows.Globalization.NumberFormatting.SignificantDigitsNumberRounder'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Globalization.NumberFormatting.SignificantDigitsNumberRounder.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Globalization.NumberFormatting.SignificantDigitsNumberRounder: ...
    @winrt_mixinmethod
    def RoundInt32(self: win32more.Windows.Globalization.NumberFormatting.INumberRounder, value: Int32) -> Int32: ...
    @winrt_mixinmethod
    def RoundUInt32(self: win32more.Windows.Globalization.NumberFormatting.INumberRounder, value: UInt32) -> UInt32: ...
    @winrt_mixinmethod
    def RoundInt64(self: win32more.Windows.Globalization.NumberFormatting.INumberRounder, value: Int64) -> Int64: ...
    @winrt_mixinmethod
    def RoundUInt64(self: win32more.Windows.Globalization.NumberFormatting.INumberRounder, value: UInt64) -> UInt64: ...
    @winrt_mixinmethod
    def RoundSingle(self: win32more.Windows.Globalization.NumberFormatting.INumberRounder, value: Single) -> Single: ...
    @winrt_mixinmethod
    def RoundDouble(self: win32more.Windows.Globalization.NumberFormatting.INumberRounder, value: Double) -> Double: ...
    @winrt_mixinmethod
    def get_RoundingAlgorithm(self: win32more.Windows.Globalization.NumberFormatting.ISignificantDigitsNumberRounder) -> win32more.Windows.Globalization.NumberFormatting.RoundingAlgorithm: ...
    @winrt_mixinmethod
    def put_RoundingAlgorithm(self: win32more.Windows.Globalization.NumberFormatting.ISignificantDigitsNumberRounder, value: win32more.Windows.Globalization.NumberFormatting.RoundingAlgorithm) -> Void: ...
    @winrt_mixinmethod
    def get_SignificantDigits(self: win32more.Windows.Globalization.NumberFormatting.ISignificantDigitsNumberRounder) -> UInt32: ...
    @winrt_mixinmethod
    def put_SignificantDigits(self: win32more.Windows.Globalization.NumberFormatting.ISignificantDigitsNumberRounder, value: UInt32) -> Void: ...
    RoundingAlgorithm = property(get_RoundingAlgorithm, put_RoundingAlgorithm)
    SignificantDigits = property(get_SignificantDigits, put_SignificantDigits)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel.Core
import win32more.Windows.System
import win32more.Windows.UI.Core
import win32more.Windows.UI.Input
import win32more.Windows.UI.Input.Core
import win32more.Windows.Win32.System.WinRT
class IRadialControllerIndependentInputSource(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Input.Core.IRadialControllerIndependentInputSource'
    _iid_ = Guid('{3d577ef6-4cee-11e6-b535-001bdc06ab3b}')
    @winrt_commethod(6)
    def get_Controller(self) -> win32more.Windows.UI.Input.RadialController: ...
    @winrt_commethod(7)
    def get_Dispatcher(self) -> win32more.Windows.UI.Core.CoreDispatcher: ...
    Controller = property(get_Controller, None)
    Dispatcher = property(get_Dispatcher, None)
class IRadialControllerIndependentInputSource2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Input.Core.IRadialControllerIndependentInputSource2'
    _iid_ = Guid('{7073aad8-35f3-4eeb-8751-be4d0a66faf4}')
    @winrt_commethod(6)
    def get_DispatcherQueue(self) -> win32more.Windows.System.DispatcherQueue: ...
    DispatcherQueue = property(get_DispatcherQueue, None)
class IRadialControllerIndependentInputSourceStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Input.Core.IRadialControllerIndependentInputSourceStatics'
    _iid_ = Guid('{3d577ef5-4cee-11e6-b535-001bdc06ab3b}')
    @winrt_commethod(6)
    def CreateForView(self, view: win32more.Windows.ApplicationModel.Core.CoreApplicationView) -> win32more.Windows.UI.Input.Core.RadialControllerIndependentInputSource: ...
class RadialControllerIndependentInputSource(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Input.Core.IRadialControllerIndependentInputSource
    _classid_ = 'Windows.UI.Input.Core.RadialControllerIndependentInputSource'
    @winrt_mixinmethod
    def get_Controller(self: win32more.Windows.UI.Input.Core.IRadialControllerIndependentInputSource) -> win32more.Windows.UI.Input.RadialController: ...
    @winrt_mixinmethod
    def get_Dispatcher(self: win32more.Windows.UI.Input.Core.IRadialControllerIndependentInputSource) -> win32more.Windows.UI.Core.CoreDispatcher: ...
    @winrt_mixinmethod
    def get_DispatcherQueue(self: win32more.Windows.UI.Input.Core.IRadialControllerIndependentInputSource2) -> win32more.Windows.System.DispatcherQueue: ...
    @winrt_classmethod
    def CreateForView(cls: win32more.Windows.UI.Input.Core.IRadialControllerIndependentInputSourceStatics, view: win32more.Windows.ApplicationModel.Core.CoreApplicationView) -> win32more.Windows.UI.Input.Core.RadialControllerIndependentInputSource: ...
    Controller = property(get_Controller, None)
    Dispatcher = property(get_Dispatcher, None)
    DispatcherQueue = property(get_DispatcherQueue, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Devices.Sensors.Custom
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Win32.System.WinRT
class CustomSensor(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Sensors.Custom.ICustomSensor
    _classid_ = 'Windows.Devices.Sensors.Custom.CustomSensor'
    @winrt_mixinmethod
    def GetCurrentReading(self: win32more.Windows.Devices.Sensors.Custom.ICustomSensor) -> win32more.Windows.Devices.Sensors.Custom.CustomSensorReading: ...
    @winrt_mixinmethod
    def get_MinimumReportInterval(self: win32more.Windows.Devices.Sensors.Custom.ICustomSensor) -> UInt32: ...
    @winrt_mixinmethod
    def put_ReportInterval(self: win32more.Windows.Devices.Sensors.Custom.ICustomSensor, value: UInt32) -> Void: ...
    @winrt_mixinmethod
    def get_ReportInterval(self: win32more.Windows.Devices.Sensors.Custom.ICustomSensor) -> UInt32: ...
    @winrt_mixinmethod
    def get_DeviceId(self: win32more.Windows.Devices.Sensors.Custom.ICustomSensor) -> WinRT_String: ...
    @winrt_mixinmethod
    def add_ReadingChanged(self: win32more.Windows.Devices.Sensors.Custom.ICustomSensor, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.Sensors.Custom.CustomSensor, win32more.Windows.Devices.Sensors.Custom.CustomSensorReadingChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ReadingChanged(self: win32more.Windows.Devices.Sensors.Custom.ICustomSensor, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def put_ReportLatency(self: win32more.Windows.Devices.Sensors.Custom.ICustomSensor2, value: UInt32) -> Void: ...
    @winrt_mixinmethod
    def get_ReportLatency(self: win32more.Windows.Devices.Sensors.Custom.ICustomSensor2) -> UInt32: ...
    @winrt_mixinmethod
    def get_MaxBatchSize(self: win32more.Windows.Devices.Sensors.Custom.ICustomSensor2) -> UInt32: ...
    @winrt_classmethod
    def GetDeviceSelector(cls: win32more.Windows.Devices.Sensors.Custom.ICustomSensorStatics, interfaceId: Guid) -> WinRT_String: ...
    @winrt_classmethod
    def FromIdAsync(cls: win32more.Windows.Devices.Sensors.Custom.ICustomSensorStatics, sensorId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.Sensors.Custom.CustomSensor]: ...
    DeviceId = property(get_DeviceId, None)
    MaxBatchSize = property(get_MaxBatchSize, None)
    MinimumReportInterval = property(get_MinimumReportInterval, None)
    ReportInterval = property(get_ReportInterval, put_ReportInterval)
    ReportLatency = property(get_ReportLatency, put_ReportLatency)
    ReadingChanged = event()
class CustomSensorReading(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Sensors.Custom.ICustomSensorReading
    _classid_ = 'Windows.Devices.Sensors.Custom.CustomSensorReading'
    @winrt_mixinmethod
    def get_Timestamp(self: win32more.Windows.Devices.Sensors.Custom.ICustomSensorReading) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def get_Properties(self: win32more.Windows.Devices.Sensors.Custom.ICustomSensorReading) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def get_PerformanceCount(self: win32more.Windows.Devices.Sensors.Custom.ICustomSensorReading2) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]: ...
    PerformanceCount = property(get_PerformanceCount, None)
    Properties = property(get_Properties, None)
    Timestamp = property(get_Timestamp, None)
class CustomSensorReadingChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Devices.Sensors.Custom.ICustomSensorReadingChangedEventArgs
    _classid_ = 'Windows.Devices.Sensors.Custom.CustomSensorReadingChangedEventArgs'
    @winrt_mixinmethod
    def get_Reading(self: win32more.Windows.Devices.Sensors.Custom.ICustomSensorReadingChangedEventArgs) -> win32more.Windows.Devices.Sensors.Custom.CustomSensorReading: ...
    Reading = property(get_Reading, None)
class ICustomSensor(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Sensors.Custom.ICustomSensor'
    _iid_ = Guid('{a136f9ad-4034-4b4d-99dd-531aac649c09}')
    @winrt_commethod(6)
    def GetCurrentReading(self) -> win32more.Windows.Devices.Sensors.Custom.CustomSensorReading: ...
    @winrt_commethod(7)
    def get_MinimumReportInterval(self) -> UInt32: ...
    @winrt_commethod(8)
    def put_ReportInterval(self, value: UInt32) -> Void: ...
    @winrt_commethod(9)
    def get_ReportInterval(self) -> UInt32: ...
    @winrt_commethod(10)
    def get_DeviceId(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def add_ReadingChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Devices.Sensors.Custom.CustomSensor, win32more.Windows.Devices.Sensors.Custom.CustomSensorReadingChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(12)
    def remove_ReadingChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    DeviceId = property(get_DeviceId, None)
    MinimumReportInterval = property(get_MinimumReportInterval, None)
    ReportInterval = property(get_ReportInterval, put_ReportInterval)
    ReadingChanged = event()
class ICustomSensor2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Sensors.Custom.ICustomSensor2'
    _iid_ = Guid('{20db3111-ec58-4d9f-bfbd-e77825088510}')
    @winrt_commethod(6)
    def put_ReportLatency(self, value: UInt32) -> Void: ...
    @winrt_commethod(7)
    def get_ReportLatency(self) -> UInt32: ...
    @winrt_commethod(8)
    def get_MaxBatchSize(self) -> UInt32: ...
    MaxBatchSize = property(get_MaxBatchSize, None)
    ReportLatency = property(get_ReportLatency, put_ReportLatency)
class ICustomSensorReading(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Sensors.Custom.ICustomSensorReading'
    _iid_ = Guid('{64004f4d-446a-4366-a87a-5f963268ec53}')
    @winrt_commethod(6)
    def get_Timestamp(self) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_commethod(7)
    def get_Properties(self) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    Properties = property(get_Properties, None)
    Timestamp = property(get_Timestamp, None)
class ICustomSensorReading2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Sensors.Custom.ICustomSensorReading2'
    _iid_ = Guid('{223c98ea-bf73-4992-9a48-d3c897594ccb}')
    @winrt_commethod(6)
    def get_PerformanceCount(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]: ...
    PerformanceCount = property(get_PerformanceCount, None)
class ICustomSensorReadingChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Sensors.Custom.ICustomSensorReadingChangedEventArgs'
    _iid_ = Guid('{6b202023-cffd-4cc1-8ff0-e21823d76fcc}')
    @winrt_commethod(6)
    def get_Reading(self) -> win32more.Windows.Devices.Sensors.Custom.CustomSensorReading: ...
    Reading = property(get_Reading, None)
class ICustomSensorStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Sensors.Custom.ICustomSensorStatics'
    _iid_ = Guid('{992052cf-f422-4c7d-836b-e7dc74a7124b}')
    @winrt_commethod(6)
    def GetDeviceSelector(self, interfaceId: Guid) -> WinRT_String: ...
    @winrt_commethod(7)
    def FromIdAsync(self, sensorId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Devices.Sensors.Custom.CustomSensor]: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.CorrelationVector
RTL_CORRELATION_VECTOR_STRING_LENGTH: UInt32 = 129
RTL_CORRELATION_VECTOR_V1_PREFIX_LENGTH: UInt32 = 16
RTL_CORRELATION_VECTOR_V1_LENGTH: UInt32 = 64
RTL_CORRELATION_VECTOR_V2_PREFIX_LENGTH: UInt32 = 22
RTL_CORRELATION_VECTOR_V2_LENGTH: UInt32 = 128
@winfunctype('ntdll.dll')
def RtlInitializeCorrelationVector(CorrelationVector: POINTER(win32more.Windows.Win32.System.CorrelationVector.CORRELATION_VECTOR), Version: Int32, Guid: POINTER(Guid)) -> UInt32: ...
@winfunctype('ntdll.dll')
def RtlIncrementCorrelationVector(CorrelationVector: POINTER(win32more.Windows.Win32.System.CorrelationVector.CORRELATION_VECTOR)) -> UInt32: ...
@winfunctype('ntdll.dll')
def RtlExtendCorrelationVector(CorrelationVector: POINTER(win32more.Windows.Win32.System.CorrelationVector.CORRELATION_VECTOR)) -> UInt32: ...
@winfunctype('ntdll.dll')
def RtlValidateCorrelationVector(Vector: POINTER(win32more.Windows.Win32.System.CorrelationVector.CORRELATION_VECTOR)) -> UInt32: ...
class CORRELATION_VECTOR(Structure):
    Version: win32more.Windows.Win32.Foundation.CHAR
    Vector: win32more.Windows.Win32.Foundation.CHAR * 129


make_ready(__name__)
